@@ -1,32 +1,27 @@
 """
 Activity APIs provide access to notifications, subscriptions, and timelines.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Activity:
-    # pylint: disable=too-many-public-methods
     """
     Activity APIs provide access to notifications, subscriptions, and timelines.
     """
 
     def __init__(self, client):
         """
-        Initialize the Activity class.
+        Initializes the Activity class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_public_events(self, params=None, payload=None):
         """
+        Summary:
         List public events
+        Docs:
         https://docs.github.com/rest/reference/activity#list-public-events
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + "/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -34,13 +29,10 @@ class Activity:
 
     def get_feeds(self, params=None, payload=None):
         """
+        Summary:
         Get feeds
+        Docs:
         https://docs.github.com/rest/reference/activity#get-feeds
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/feeds"
         response = self._execute("get", url, params=params, payload=payload)
@@ -50,15 +42,10 @@ class Activity:
         self, owner, repo, params=None, payload=None
     ):
         """
+        Summary:
         List public events for a network of repositories
+        Docs:
         https://docs.github.com/rest/reference/activity#list-public-events-for-a-network-of-repositories
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/networks/{owner}/{repo}/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -66,18 +53,10 @@ class Activity:
 
     def list_notifications_for_the_authenticated_user(self, params=None, payload=None):
         """
+        Summary:
         List notifications for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-notifications-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        all
-         participating
-         since
-         before
-         per-page
-         page
         """
         url = self._base_url + "/notifications"
         response = self._execute("get", url, params=params, payload=payload)
@@ -85,13 +64,10 @@ class Activity:
 
     def mark_notifications_as_read(self, params=None, payload=None):
         """
+        Summary:
         Mark notifications as read
+        Docs:
         https://docs.github.com/rest/reference/activity#mark-notifications-as-read
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/notifications"
         response = self._execute("put", url, params=params, payload=payload)
@@ -99,13 +75,10 @@ class Activity:
 
     def get_a_thread(self, thread_id, params=None, payload=None):
         """
+        Summary:
         Get a thread
+        Docs:
         https://docs.github.com/rest/reference/activity#get-a-thread
-        Attributes:
-        Path Parameters:
-        thread_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/notifications/threads/{thread_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -113,13 +86,10 @@ class Activity:
 
     def mark_a_thread_as_read(self, thread_id, params=None, payload=None):
         """
+        Summary:
         Mark a thread as read
+        Docs:
         https://docs.github.com/rest/reference/activity#mark-a-thread-as-read
-        Attributes:
-        Path Parameters:
-        thread_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/notifications/threads/{thread_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -129,13 +99,10 @@ class Activity:
         self, thread_id, params=None, payload=None
     ):
         """
+        Summary:
         Get a thread subscription for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#get-a-thread-subscription-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        thread_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/notifications/threads/{thread_id}/subscription"
         response = self._execute("get", url, params=params, payload=payload)
@@ -143,13 +110,10 @@ class Activity:
 
     def set_a_thread_subscription(self, thread_id, params=None, payload=None):
         """
+        Summary:
         Set a thread subscription
+        Docs:
         https://docs.github.com/rest/reference/activity#set-a-thread-subscription
-        Attributes:
-        Path Parameters:
-        thread_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/notifications/threads/{thread_id}/subscription"
         response = self._execute("put", url, params=params, payload=payload)
@@ -157,13 +121,10 @@ class Activity:
 
     def delete_a_thread_subscription(self, thread_id, params=None, payload=None):
         """
+        Summary:
         Delete a thread subscription
+        Docs:
         https://docs.github.com/rest/reference/activity#delete-a-thread-subscription
-        Attributes:
-        Path Parameters:
-        thread_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/notifications/threads/{thread_id}/subscription"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -171,14 +132,10 @@ class Activity:
 
     def list_public_organization_events(self, org, params=None, payload=None):
         """
+        Summary:
         List public organization events
+        Docs:
         https://docs.github.com/rest/reference/activity#list-public-organization-events
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/orgs/{org}/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -186,15 +143,10 @@ class Activity:
 
     def list_repository_events(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List repository events
+        Docs:
         https://docs.github.com/rest/reference/activity#list-repository-events
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -204,19 +156,10 @@ class Activity:
         self, owner, repo, params=None, payload=None
     ):
         """
+        Summary:
         List repository notifications for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-repository-notifications-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        all
-         participating
-         since
-         before
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/notifications"
         response = self._execute("get", url, params=params, payload=payload)
@@ -224,14 +167,10 @@ class Activity:
 
     def mark_repository_notifications_as_read(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Mark repository notifications as read
+        Docs:
         https://docs.github.com/rest/reference/activity#mark-repository-notifications-as-read
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/notifications"
         response = self._execute("put", url, params=params, payload=payload)
@@ -239,15 +178,10 @@ class Activity:
 
     def list_stargazers(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List stargazers
+        Docs:
         https://docs.github.com/rest/reference/activity#list-stargazers
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/stargazers"
         response = self._execute("get", url, params=params, payload=payload)
@@ -255,15 +189,10 @@ class Activity:
 
     def list_watchers(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List watchers
+        Docs:
         https://docs.github.com/rest/reference/activity#list-watchers
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/subscribers"
         response = self._execute("get", url, params=params, payload=payload)
@@ -271,14 +200,10 @@ class Activity:
 
     def get_a_repository_subscription(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Get a repository subscription
+        Docs:
         https://docs.github.com/rest/reference/activity#get-a-repository-subscription
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/subscription"
         response = self._execute("get", url, params=params, payload=payload)
@@ -286,14 +211,10 @@ class Activity:
 
     def set_a_repository_subscription(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Set a repository subscription
+        Docs:
         https://docs.github.com/rest/reference/activity#set-a-repository-subscription
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/subscription"
         response = self._execute("put", url, params=params, payload=payload)
@@ -301,14 +222,10 @@ class Activity:
 
     def delete_a_repository_subscription(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Delete a repository subscription
+        Docs:
         https://docs.github.com/rest/reference/activity#delete-a-repository-subscription
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/subscription"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -316,16 +233,10 @@ class Activity:
 
     def list_repositories_starred_by_the_authenticated_user(self, params=None, payload=None):
         """
+        Summary:
         List repositories starred by the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-repositories-starred-by-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        sort
-         direction
-         per-page
-         page
         """
         url = self._base_url + "/user/starred"
         response = self._execute("get", url, params=params, payload=payload)
@@ -335,14 +246,10 @@ class Activity:
         self, owner, repo, params=None, payload=None
     ):
         """
+        Summary:
         Check if a repository is starred by the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#check-if-a-repository-is-starred-by-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/starred/{owner}/{repo}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -350,14 +257,10 @@ class Activity:
 
     def star_a_repository_for_the_authenticated_user(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Star a repository for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#star-a-repository-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/starred/{owner}/{repo}"
         response = self._execute("put", url, params=params, payload=payload)
@@ -367,14 +270,10 @@ class Activity:
         self, owner, repo, params=None, payload=None
     ):
         """
+        Summary:
         Unstar a repository for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#unstar-a-repository-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/starred/{owner}/{repo}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -382,14 +281,10 @@ class Activity:
 
     def list_repositories_watched_by_the_authenticated_user(self, params=None, payload=None):
         """
+        Summary:
         List repositories watched by the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-repositories-watched-by-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + "/user/subscriptions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -397,14 +292,10 @@ class Activity:
 
     def list_events_for_the_authenticated_user(self, username, params=None, payload=None):
         """
+        Summary:
         List events for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-events-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/users/{username}/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -414,15 +305,10 @@ class Activity:
         self, username, org, params=None, payload=None
     ):
         """
+        Summary:
         List organization events for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-organization-events-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        username
-        org
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/users/{username}/events/orgs/{org}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -430,14 +316,10 @@ class Activity:
 
     def list_public_events_for_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         List public events for a user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-public-events-for-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/users/{username}/events/public"
         response = self._execute("get", url, params=params, payload=payload)
@@ -445,14 +327,10 @@ class Activity:
 
     def list_events_received_by_the_authenticated_user(self, username, params=None, payload=None):
         """
+        Summary:
         List events received by the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-events-received-by-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/users/{username}/received_events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -460,14 +338,10 @@ class Activity:
 
     def list_public_events_received_by_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         List public events received by a user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-public-events-received-by-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/users/{username}/received_events/public"
         response = self._execute("get", url, params=params, payload=payload)
@@ -475,16 +349,10 @@ class Activity:
 
     def list_repositories_starred_by_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         List repositories starred by a user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-repositories-starred-by-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        sort
-         direction
-         per-page
-         page
         """
         url = self._base_url + f"/users/{username}/starred"
         response = self._execute("get", url, params=params, payload=payload)
@@ -492,14 +360,10 @@ class Activity:
 
     def list_repositories_watched_by_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         List repositories watched by a user
+        Docs:
         https://docs.github.com/rest/reference/activity#list-repositories-watched-by-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/users/{username}/subscriptions"
         response = self._execute("get", url, params=params, payload=payload)
