@@ -1,9 +1,9 @@
 """
 Monitor charges and usage from Actions and Packages.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Billing:
     """
     Monitor charges and usage from Actions and Packages.
@@ -11,79 +11,30 @@ class Billing:
 
     def __init__(self, client):
         """
-        Initialize the Billing class.
+        Initializes the Billing class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def get_github_actions_billing_for_an_enterprise(self, enterprise, params=None, payload=None):
-        """
-        Get GitHub Actions billing for an enterprise
-        https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-an-enterprise
-        Attributes:
-        Path Parameters:
-        enterprise
-        Payload Parameters:
-
-        """
-        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/actions"
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
     def get_github_advanced_security_active_committers_for_an_enterprise(
         self, enterprise, params=None, payload=None
     ):
         """
+        Summary:
         Get GitHub Advanced Security active committers for an enterprise
+        Docs:
         https://docs.github.com/rest/reference/billing#export-advanced-security-active-committers-data-for-enterprise
-        Attributes:
-        Path Parameters:
-        enterprise
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/enterprises/{enterprise}/settings/billing/advanced-security"
         response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_github_packages_billing_for_an_enterprise(self, enterprise, params=None, payload=None):
-        """
-        Get GitHub Packages billing for an enterprise
-        https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-an-enterprise
-        Attributes:
-        Path Parameters:
-        enterprise
-        Payload Parameters:
-
-        """
-        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/packages"
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
-    def get_shared_storage_billing_for_an_enterprise(self, enterprise, params=None, payload=None):
-        """
-        Get shared storage billing for an enterprise
-        https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-an-enterprise
-        Attributes:
-        Path Parameters:
-        enterprise
-        Payload Parameters:
-
-        """
-        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/shared-storage"
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
     def get_github_actions_billing_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         Get GitHub Actions billing for an organization
+        Docs:
         https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/settings/billing/actions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -93,14 +44,10 @@ class Billing:
         self, org, params=None, payload=None
     ):
         """
+        Summary:
         Get GitHub Advanced Security active committers for an organization
+        Docs:
         https://docs.github.com/rest/reference/billing#get-github-advanced-security-active-committers-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/orgs/{org}/settings/billing/advanced-security"
         response = self._execute("get", url, params=params, payload=payload)
@@ -108,13 +55,10 @@ class Billing:
 
     def get_github_packages_billing_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         Get GitHub Packages billing for an organization
+        Docs:
         https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/settings/billing/packages"
         response = self._execute("get", url, params=params, payload=payload)
@@ -122,13 +66,10 @@ class Billing:
 
     def get_shared_storage_billing_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         Get shared storage billing for an organization
+        Docs:
         https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/settings/billing/shared-storage"
         response = self._execute("get", url, params=params, payload=payload)
@@ -136,13 +77,10 @@ class Billing:
 
     def get_github_actions_billing_for_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         Get GitHub Actions billing for a user
+        Docs:
         https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/users/{username}/settings/billing/actions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -150,13 +88,10 @@ class Billing:
 
     def get_github_packages_billing_for_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         Get GitHub Packages billing for a user
+        Docs:
         https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/users/{username}/settings/billing/packages"
         response = self._execute("get", url, params=params, payload=payload)
@@ -164,13 +99,10 @@ class Billing:
 
     def get_shared_storage_billing_for_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         Get shared storage billing for a user
+        Docs:
         https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-a-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/users/{username}/settings/billing/shared-storage"
         response = self._execute("get", url, params=params, payload=payload)
