@@ -1,9 +1,9 @@
 """
 Retrieve code scanning alerts from a repository.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class CodeScanning:
     """
     Retrieve code scanning alerts from a repository.
@@ -11,28 +11,17 @@ class CodeScanning:
 
     def __init__(self, client):
         """
-        Initialize the CodeScanning class.
+        Initializes the CodeScanning class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_code_scanning_alerts_for_an_enterprise(self, enterprise, params=None, payload=None):
         """
+        Summary:
         List code scanning alerts for an enterprise
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-for-an-enterprise
-        Attributes:
-        Path Parameters:
-        enterprise
-        Payload Parameters:
-        tool-name
-         tool-guid
-         pagination-before
-         pagination-after
-         page
-         per-page
-         direction
-         state
-         sort
         """
         url = self._base_url + f"/enterprises/{enterprise}/code-scanning/alerts"
         response = self._execute("get", url, params=params, payload=payload)
@@ -40,21 +29,10 @@ class CodeScanning:
 
     def list_code_scanning_alerts_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         List code scanning alerts for an organization
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-by-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        tool-name
-         tool-guid
-         pagination-before
-         pagination-after
-         page
-         per-page
-         direction
-         state
-         sort
         """
         url = self._base_url + f"/orgs/{org}/code-scanning/alerts"
         response = self._execute("get", url, params=params, payload=payload)
@@ -62,21 +40,10 @@ class CodeScanning:
 
     def list_code_scanning_alerts_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List code scanning alerts for a repository
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        tool-name
-         tool-guid
-         page
-         per-page
-         git-ref
-         direction
-         sort
-         state
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts"
         response = self._execute("get", url, params=params, payload=payload)
@@ -84,15 +51,10 @@ class CodeScanning:
 
     def get_a_code_scanning_alert(self, owner, repo, alert_number, params=None, payload=None):
         """
+        Summary:
         Get a code scanning alert
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#get-a-code-scanning-alert
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        alert_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts/{alert_number}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -100,15 +62,10 @@ class CodeScanning:
 
     def update_a_code_scanning_alert(self, owner, repo, alert_number, params=None, payload=None):
         """
+        Summary:
         Update a code scanning alert
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#update-a-code-scanning-alert
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        alert_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts/{alert_number}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -118,17 +75,10 @@ class CodeScanning:
         self, owner, repo, alert_number, params=None, payload=None
     ):
         """
+        Summary:
         List instances of a code scanning alert
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#list-instances-of-a-code-scanning-alert
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        alert_number
-        Payload Parameters:
-        page
-         per-page
-         git-ref
         """
         url = (
             self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts/{alert_number}/instances"
@@ -138,19 +88,10 @@ class CodeScanning:
 
     def list_code_scanning_analyses_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List code scanning analyses for a repository
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#list-code-scanning-analyses-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        tool-name
-         tool-guid
-         page
-         per-page
-         ref
-         sarif_id
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/analyses"
         response = self._execute("get", url, params=params, payload=payload)
@@ -160,15 +101,10 @@ class CodeScanning:
         self, owner, repo, analysis_id, params=None, payload=None
     ):
         """
+        Summary:
         Get a code scanning analysis for a repository
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#get-a-code-scanning-analysis-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        analysis_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/analyses/{analysis_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -178,64 +114,45 @@ class CodeScanning:
         self, owner, repo, analysis_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete a code scanning analysis from a repository
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#delete-a-code-scanning-analysis-from-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        analysis_id
-        Payload Parameters:
-        confirm_delete
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/analyses/{analysis_id}"
         response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def run_codeql_queries_against_one_or_more_repositories(
-        self, owner, repo, params=None, payload=None
-    ):
+    def list_codeql_databases_for_a_repository(self, owner, repo, params=None, payload=None):
         """
-        Run CodeQL queries against one or more repositories
-        https://docs.github.com/rest/reference/code-scanning#run-codeql-queries-against-one-or-more-repositories
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
+        Summary:
+        List CodeQL databases for a repository
+        Docs:
+        https://docs.github.com/rest/reference/code-scanning#list-codeql-databases
         """
-        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/codeql/queries"
-        response = self._execute("post", url, params=params, payload=payload)
+        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/codeql/databases"
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def put_a_summary_status_report_for_building_a_codeql_database(
-        self, owner, repo, params=None, payload=None
+    def get_a_codeql_database_for_a_repository(
+        self, owner, repo, language, params=None, payload=None
     ):
         """
-        Put a summary status report for building a CodeQL database
-        N/A
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
+        Summary:
+        Get a CodeQL database for a repository
+        Docs:
+        https://docs.github.com/rest/reference/code-scanning#get-codeql-database
         """
-        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/codeql/status"
-        response = self._execute("put", url, params=params, payload=payload)
+        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/codeql/databases/{language}"
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def upload_an_analysis_as_sarif_data(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Upload an analysis as SARIF data
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#upload-a-sarif-file
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/sarifs"
         response = self._execute("post", url, params=params, payload=payload)
@@ -245,15 +162,10 @@ class CodeScanning:
         self, owner, repo, sarif_id, params=None, payload=None
     ):
         """
+        Summary:
         Get information about a SARIF upload
+        Docs:
         https://docs.github.com/rest/reference/code-scanning#list-recent-code-scanning-analyses-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        sarif_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/sarifs/{sarif_id}"
         response = self._execute("get", url, params=params, payload=payload)
