@@ -1,9 +1,9 @@
 """
 Endpoints to manage Dependabot.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Dependabot:
     """
     Endpoints to manage Dependabot.
@@ -11,21 +11,17 @@ class Dependabot:
 
     def __init__(self, client):
         """
-        Initialize the Dependabot class.
+        Initializes the Dependabot class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_organization_secrets(self, org, params=None, payload=None):
         """
+        Summary:
         List organization secrets
+        Docs:
         https://docs.github.com/rest/reference/dependabot#list-organization-secrets
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets"
         response = self._execute("get", url, params=params, payload=payload)
@@ -33,13 +29,10 @@ class Dependabot:
 
     def get_an_organization_public_key(self, org, params=None, payload=None):
         """
+        Summary:
         Get an organization public key
+        Docs:
         https://docs.github.com/rest/reference/dependabot#get-an-organization-public-key
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets/public-key"
         response = self._execute("get", url, params=params, payload=payload)
@@ -47,14 +40,10 @@ class Dependabot:
 
     def get_an_organization_secret(self, org, secret_name, params=None, payload=None):
         """
+        Summary:
         Get an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#get-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -62,14 +51,10 @@ class Dependabot:
 
     def create_or_update_an_organization_secret(self, org, secret_name, params=None, payload=None):
         """
+        Summary:
         Create or update an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#create-or-update-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}"
         response = self._execute("put", url, params=params, payload=payload)
@@ -77,14 +62,10 @@ class Dependabot:
 
     def delete_an_organization_secret(self, org, secret_name, params=None, payload=None):
         """
+        Summary:
         Delete an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#delete-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -94,15 +75,10 @@ class Dependabot:
         self, org, secret_name, params=None, payload=None
     ):
         """
+        Summary:
         List selected repositories for an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#list-selected-repositories-for-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        Payload Parameters:
-        page
-         per-page
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}/repositories"
         response = self._execute("get", url, params=params, payload=payload)
@@ -112,14 +88,10 @@ class Dependabot:
         self, org, secret_name, params=None, payload=None
     ):
         """
+        Summary:
         Set selected repositories for an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#set-selected-repositories-for-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}/repositories"
         response = self._execute("put", url, params=params, payload=payload)
@@ -129,15 +101,10 @@ class Dependabot:
         self, org, secret_name, repository_id, params=None, payload=None
     ):
         """
+        Summary:
         Add selected repository to an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#add-selected-repository-to-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        repository_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -150,15 +117,10 @@ class Dependabot:
         self, org, secret_name, repository_id, params=None, payload=None
     ):
         """
+        Summary:
         Remove selected repository from an organization secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#remove-selected-repository-from-an-organization-secret
-        Attributes:
-        Path Parameters:
-        org
-        secret_name
-        repository_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -167,17 +129,45 @@ class Dependabot:
         response = self._execute("delete", url, params=params, payload=payload)
         return response
 
+    def list_dependabot_alerts_for_a_repository(self, owner, repo, params=None, payload=None):
+        """
+        Summary:
+        List Dependabot alerts for a repository
+        Docs:
+        https://docs.github.com/rest/reference/dependabot#list-dependabot-alerts-for-a-repository
+        """
+        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/alerts"
+        response = self._execute("get", url, params=params, payload=payload)
+        return response
+
+    def get_a_dependabot_alert(self, owner, repo, alert_number, params=None, payload=None):
+        """
+        Summary:
+        Get a Dependabot alert
+        Docs:
+        https://docs.github.com/rest/reference/dependabot#get-a-dependabot-alert
+        """
+        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/alerts/{alert_number}"
+        response = self._execute("get", url, params=params, payload=payload)
+        return response
+
+    def update_a_dependabot_alert(self, owner, repo, alert_number, params=None, payload=None):
+        """
+        Summary:
+        Update a Dependabot alert
+        Docs:
+        https://docs.github.com/rest/reference/dependabot#update-a-dependabot-alert
+        """
+        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/alerts/{alert_number}"
+        response = self._execute("patch", url, params=params, payload=payload)
+        return response
+
     def list_repository_secrets(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List repository secrets
+        Docs:
         https://docs.github.com/rest/reference/dependabot#list-repository-secrets
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets"
         response = self._execute("get", url, params=params, payload=payload)
@@ -185,14 +175,10 @@ class Dependabot:
 
     def get_a_repository_public_key(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Get a repository public key
+        Docs:
         https://docs.github.com/rest/reference/dependabot#get-a-repository-public-key
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/public-key"
         response = self._execute("get", url, params=params, payload=payload)
@@ -200,15 +186,10 @@ class Dependabot:
 
     def get_a_repository_secret(self, owner, repo, secret_name, params=None, payload=None):
         """
+        Summary:
         Get a repository secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#get-a-repository-secret
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/{secret_name}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -218,15 +199,10 @@ class Dependabot:
         self, owner, repo, secret_name, params=None, payload=None
     ):
         """
+        Summary:
         Create or update a repository secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#create-or-update-a-repository-secret
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/{secret_name}"
         response = self._execute("put", url, params=params, payload=payload)
@@ -234,15 +210,10 @@ class Dependabot:
 
     def delete_a_repository_secret(self, owner, repo, secret_name, params=None, payload=None):
         """
+        Summary:
         Delete a repository secret
+        Docs:
         https://docs.github.com/rest/reference/dependabot#delete-a-repository-secret
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        secret_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/{secret_name}"
         response = self._execute("delete", url, params=params, payload=payload)
