@@ -1,9 +1,9 @@
 """
 View gitignore templates
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Gitignore:
     """
     View gitignore templates
@@ -11,20 +11,17 @@ class Gitignore:
 
     def __init__(self, client):
         """
-        Initialize the Gitignore class.
+        Initializes the Gitignore class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def get_all_gitignore_templates(self, params=None, payload=None):
         """
+        Summary:
         Get all gitignore templates
+        Docs:
         https://docs.github.com/rest/reference/gitignore#get-all-gitignore-templates
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/gitignore/templates"
         response = self._execute("get", url, params=params, payload=payload)
@@ -32,14 +29,10 @@ class Gitignore:
 
     def get_a_gitignore_template(self, name, params=None, payload=None):
         """
+        Summary:
         Get a gitignore template
+        Docs:
         https://docs.github.com/rest/reference/gitignore#get-a-gitignore-template
-        Attributes:
-        Path Parameters:
-        name
-        name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/gitignore/templates/{name}"
         response = self._execute("get", url, params=params, payload=payload)
