@@ -1,9 +1,9 @@
 """
 Owner or admin management of users interactions.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Interactions:
     """
     Owner or admin management of users interactions.
@@ -11,20 +11,17 @@ class Interactions:
 
     def __init__(self, client):
         """
-        Initialize the Interactions class.
+        Initializes the Interactions class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def get_interaction_restrictions_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         Get interaction restrictions for an organization
+        Docs:
         https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/interaction-limits"
         response = self._execute("get", url, params=params, payload=payload)
@@ -32,13 +29,10 @@ class Interactions:
 
     def set_interaction_restrictions_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         Set interaction restrictions for an organization
+        Docs:
         https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/interaction-limits"
         response = self._execute("put", url, params=params, payload=payload)
@@ -46,13 +40,10 @@ class Interactions:
 
     def remove_interaction_restrictions_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         Remove interaction restrictions for an organization
+        Docs:
         https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/interaction-limits"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -60,14 +51,10 @@ class Interactions:
 
     def get_interaction_restrictions_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Get interaction restrictions for a repository
+        Docs:
         https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/interaction-limits"
         response = self._execute("get", url, params=params, payload=payload)
@@ -75,14 +62,10 @@ class Interactions:
 
     def set_interaction_restrictions_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Set interaction restrictions for a repository
+        Docs:
         https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/interaction-limits"
         response = self._execute("put", url, params=params, payload=payload)
@@ -92,14 +75,10 @@ class Interactions:
         self, owner, repo, params=None, payload=None
     ):
         """
+        Summary:
         Remove interaction restrictions for a repository
+        Docs:
         https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/interaction-limits"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -107,13 +86,10 @@ class Interactions:
 
     def get_interaction_restrictions_for_your_public_repositories(self, params=None, payload=None):
         """
+        Summary:
         Get interaction restrictions for your public repositories
+        Docs:
         https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-your-public-repositories
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/user/interaction-limits"
         response = self._execute("get", url, params=params, payload=payload)
@@ -121,13 +97,10 @@ class Interactions:
 
     def set_interaction_restrictions_for_your_public_repositories(self, params=None, payload=None):
         """
+        Summary:
         Set interaction restrictions for your public repositories
+        Docs:
         https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-your-public-repositories
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/user/interaction-limits"
         response = self._execute("put", url, params=params, payload=payload)
@@ -137,13 +110,10 @@ class Interactions:
         self, params=None, payload=None
     ):
         """
+        Summary:
         Remove interaction restrictions from your public repositories
+        Docs:
         https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-from-your-public-repositories
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/user/interaction-limits"
         response = self._execute("delete", url, params=params, payload=payload)
