@@ -1,42 +1,27 @@
 """
 Interact with GitHub Issues.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Issues:
-    # pylint: disable=too-many-public-methods
     """
     Interact with GitHub Issues.
     """
 
     def __init__(self, client):
         """
-        Initialize the Issues class.
+        Initializes the Issues class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_issues_assigned_to_the_authenticated_user(self, params=None, payload=None):
         """
+        Summary:
         List issues assigned to the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/issues#list-issues-assigned-to-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        filter
-         state
-         labels
-         sort
-         direction
-         since
-         collab
-         orgs
-         owned
-         pulls
-         per-page
-         page
         """
         url = self._base_url + "/issues"
         response = self._execute("get", url, params=params, payload=payload)
@@ -46,20 +31,10 @@ class Issues:
         self, org, params=None, payload=None
     ):
         """
+        Summary:
         List organization issues assigned to the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/issues#list-organization-issues-assigned-to-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        filter
-         state
-         labels
-         sort
-         direction
-         since
-         per-page
-         page
         """
         url = self._base_url + f"/orgs/{org}/issues"
         response = self._execute("get", url, params=params, payload=payload)
@@ -67,15 +42,10 @@ class Issues:
 
     def list_assignees(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List assignees
+        Docs:
         https://docs.github.com/rest/reference/issues#list-assignees
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/assignees"
         response = self._execute("get", url, params=params, payload=payload)
@@ -83,15 +53,10 @@ class Issues:
 
     def check_if_a_user_can_be_assigned(self, owner, repo, assignee, params=None, payload=None):
         """
+        Summary:
         Check if a user can be assigned
+        Docs:
         https://docs.github.com/rest/reference/issues#check-if-a-user-can-be-assigned
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        assignee
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/assignees/{assignee}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -99,24 +64,10 @@ class Issues:
 
     def list_repository_issues(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List repository issues
+        Docs:
         https://docs.github.com/rest/reference/issues#list-repository-issues
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        milestone
-         state
-         assignee
-         creator
-         mentioned
-         labels
-         sort
-         direction
-         since
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues"
         response = self._execute("get", url, params=params, payload=payload)
@@ -124,14 +75,10 @@ class Issues:
 
     def create_an_issue(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#create-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues"
         response = self._execute("post", url, params=params, payload=payload)
@@ -139,18 +86,10 @@ class Issues:
 
     def list_issue_comments_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List issue comments for a repository
+        Docs:
         https://docs.github.com/rest/reference/issues#list-issue-comments-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        sort
-         direction
-         since
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments"
         response = self._execute("get", url, params=params, payload=payload)
@@ -158,15 +97,10 @@ class Issues:
 
     def get_an_issue_comment(self, owner, repo, comment_id, params=None, payload=None):
         """
+        Summary:
         Get an issue comment
+        Docs:
         https://docs.github.com/rest/reference/issues#get-an-issue-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -174,15 +108,10 @@ class Issues:
 
     def update_an_issue_comment(self, owner, repo, comment_id, params=None, payload=None):
         """
+        Summary:
         Update an issue comment
+        Docs:
         https://docs.github.com/rest/reference/issues#update-an-issue-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -190,15 +119,10 @@ class Issues:
 
     def delete_an_issue_comment(self, owner, repo, comment_id, params=None, payload=None):
         """
+        Summary:
         Delete an issue comment
+        Docs:
         https://docs.github.com/rest/reference/issues#delete-an-issue-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -206,15 +130,10 @@ class Issues:
 
     def list_issue_events_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List issue events for a repository
+        Docs:
         https://docs.github.com/rest/reference/issues#list-issue-events-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -222,15 +141,10 @@ class Issues:
 
     def get_an_issue_event(self, owner, repo, event_id, params=None, payload=None):
         """
+        Summary:
         Get an issue event
+        Docs:
         https://docs.github.com/rest/reference/issues#get-an-issue-event
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        event_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/events/{event_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -238,15 +152,10 @@ class Issues:
 
     def get_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Get an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#get-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -254,15 +163,10 @@ class Issues:
 
     def update_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Update an issue
+        Docs:
         https://docs.github.com/rest/reference/issues/#update-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -270,15 +174,10 @@ class Issues:
 
     def add_assignees_to_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Add assignees to an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#add-assignees-to-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/assignees"
         response = self._execute("post", url, params=params, payload=payload)
@@ -286,15 +185,10 @@ class Issues:
 
     def remove_assignees_from_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Remove assignees from an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#remove-assignees-from-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/assignees"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -302,17 +196,10 @@ class Issues:
 
     def list_issue_comments(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         List issue comments
+        Docs:
         https://docs.github.com/rest/reference/issues#list-issue-comments
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-        since
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/comments"
         response = self._execute("get", url, params=params, payload=payload)
@@ -320,15 +207,10 @@ class Issues:
 
     def create_an_issue_comment(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Create an issue comment
+        Docs:
         https://docs.github.com/rest/reference/issues#create-an-issue-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/comments"
         response = self._execute("post", url, params=params, payload=payload)
@@ -336,16 +218,10 @@ class Issues:
 
     def list_issue_events(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         List issue events
+        Docs:
         https://docs.github.com/rest/reference/issues#list-issue-events
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/events"
         response = self._execute("get", url, params=params, payload=payload)
@@ -353,16 +229,10 @@ class Issues:
 
     def list_labels_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         List labels for an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#list-labels-for-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
         response = self._execute("get", url, params=params, payload=payload)
@@ -370,15 +240,10 @@ class Issues:
 
     def add_labels_to_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Add labels to an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#add-labels-to-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
         response = self._execute("post", url, params=params, payload=payload)
@@ -386,15 +251,10 @@ class Issues:
 
     def set_labels_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Set labels for an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#set-labels-for-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
         response = self._execute("put", url, params=params, payload=payload)
@@ -402,15 +262,10 @@ class Issues:
 
     def remove_all_labels_from_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Remove all labels from an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#remove-all-labels-from-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -419,18 +274,11 @@ class Issues:
     def remove_a_label_from_an_issue(
         self, owner, repo, issue_number, name, params=None, payload=None
     ):
-
         """
+        Summary:
         Remove a label from an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#remove-a-label-from-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels/{name}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -438,15 +286,10 @@ class Issues:
 
     def lock_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Lock an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#lock-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/lock"
         response = self._execute("put", url, params=params, payload=payload)
@@ -454,15 +297,10 @@ class Issues:
 
     def unlock_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Unlock an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#unlock-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/lock"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -472,16 +310,10 @@ class Issues:
         self, owner, repo, issue_number, params=None, payload=None
     ):
         """
+        Summary:
         List timeline events for an issue
+        Docs:
         https://docs.github.com/rest/reference/issues#list-timeline-events-for-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/timeline"
         response = self._execute("get", url, params=params, payload=payload)
@@ -489,15 +321,10 @@ class Issues:
 
     def list_labels_for_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List labels for a repository
+        Docs:
         https://docs.github.com/rest/reference/issues#list-labels-for-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels"
         response = self._execute("get", url, params=params, payload=payload)
@@ -505,14 +332,10 @@ class Issues:
 
     def create_a_label(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a label
+        Docs:
         https://docs.github.com/rest/reference/issues#create-a-label
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels"
         response = self._execute("post", url, params=params, payload=payload)
@@ -520,15 +343,10 @@ class Issues:
 
     def get_a_label(self, owner, repo, name, params=None, payload=None):
         """
+        Summary:
         Get a label
+        Docs:
         https://docs.github.com/rest/reference/issues#get-a-label
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -536,15 +354,10 @@ class Issues:
 
     def update_a_label(self, owner, repo, name, params=None, payload=None):
         """
+        Summary:
         Update a label
+        Docs:
         https://docs.github.com/rest/reference/issues#update-a-label
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -552,15 +365,10 @@ class Issues:
 
     def delete_a_label(self, owner, repo, name, params=None, payload=None):
         """
+        Summary:
         Delete a label
+        Docs:
         https://docs.github.com/rest/reference/issues#delete-a-label
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -568,18 +376,10 @@ class Issues:
 
     def list_milestones(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List milestones
+        Docs:
         https://docs.github.com/rest/reference/issues#list-milestones
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        state
-         sort
-         direction
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones"
         response = self._execute("get", url, params=params, payload=payload)
@@ -587,14 +387,10 @@ class Issues:
 
     def create_a_milestone(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a milestone
+        Docs:
         https://docs.github.com/rest/reference/issues#create-a-milestone
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones"
         response = self._execute("post", url, params=params, payload=payload)
@@ -602,15 +398,10 @@ class Issues:
 
     def get_a_milestone(self, owner, repo, milestone_number, params=None, payload=None):
         """
+        Summary:
         Get a milestone
+        Docs:
         https://docs.github.com/rest/reference/issues#get-a-milestone
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        milestone_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -618,15 +409,10 @@ class Issues:
 
     def update_a_milestone(self, owner, repo, milestone_number, params=None, payload=None):
         """
+        Summary:
         Update a milestone
+        Docs:
         https://docs.github.com/rest/reference/issues#update-a-milestone
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        milestone_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -634,15 +420,10 @@ class Issues:
 
     def delete_a_milestone(self, owner, repo, milestone_number, params=None, payload=None):
         """
+        Summary:
         Delete a milestone
+        Docs:
         https://docs.github.com/rest/reference/issues#delete-a-milestone
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        milestone_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -652,16 +433,10 @@ class Issues:
         self, owner, repo, milestone_number, params=None, payload=None
     ):
         """
+        Summary:
         List labels for issues in a milestone
+        Docs:
         https://docs.github.com/rest/reference/issues#list-labels-for-issues-in-a-milestone
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        milestone_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}/labels"
         response = self._execute("get", url, params=params, payload=payload)
@@ -671,20 +446,10 @@ class Issues:
         self, params=None, payload=None
     ):
         """
+        Summary:
         List user account issues assigned to the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/issues#list-user-account-issues-assigned-to-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        filter
-         state
-         labels
-         sort
-         direction
-         since
-         per-page
-         page
         """
         url = self._base_url + "/user/issues"
         response = self._execute("get", url, params=params, payload=payload)
