@@ -1,9 +1,9 @@
 """
 Render GitHub flavored markdown
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Markdown:
     """
     Render GitHub flavored markdown
@@ -11,20 +11,17 @@ class Markdown:
 
     def __init__(self, client):
         """
-        Initialize the Markdown class.
+        Initializes the Markdown class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def render_a_markdown_document(self, params=None, payload=None):
         """
+        Summary:
         Render a Markdown document
+        Docs:
         https://docs.github.com/rest/reference/markdown#render-a-markdown-document
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/markdown"
         response = self._execute("post", url, params=params, payload=payload)
@@ -32,13 +29,10 @@ class Markdown:
 
     def render_a_markdown_document_in_raw_mode(self, params=None, payload=None):
         """
+        Summary:
         Render a Markdown document in raw mode
+        Docs:
         https://docs.github.com/rest/reference/markdown#render-a-markdown-document-in-raw-mode
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/markdown/raw"
         response = self._execute("post", url, params=params, payload=payload)
