@@ -1,32 +1,27 @@
 """
 Manage packages for authenticated users and organizations.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Packages:
-    # pylint: disable=too-many-public-methods
     """
     Manage packages for authenticated users and organizations.
     """
 
     def __init__(self, client):
         """
-        Initialize the Packages class.
+        Initializes the Packages class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_packages_for_an_organization(self, org, params=None, payload=None):
         """
+        Summary:
         List packages for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#list-packages-for-an-organization
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        package_type
-         package-visibility
         """
         url = self._base_url + f"/orgs/{org}/packages"
         response = self._execute("get", url, params=params, payload=payload)
@@ -36,15 +31,10 @@ class Packages:
         self, package_type, package_name, org, params=None, payload=None
     ):
         """
+        Summary:
         Get a package for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#get-a-package-for-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/packages/{package_type}/{package_name}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -54,15 +44,10 @@ class Packages:
         self, package_type, package_name, org, params=None, payload=None
     ):
         """
+        Summary:
         Delete a package for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#delete-a-package-for-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/packages/{package_type}/{package_name}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -72,54 +57,42 @@ class Packages:
         self, package_type, package_name, org, params=None, payload=None
     ):
         """
+        Summary:
         Restore a package for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#restore-a-package-for-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        Payload Parameters:
-        token
         """
         url = self._base_url + f"/orgs/{org}/packages/{package_type}/{package_name}/restore"
         response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_all_package_versions_for_a_package_owned_by_an_organization(
+    def list_package_versions_for_a_package_owned_by_an_organization(
         self, package_type, package_name, org, params=None, payload=None
     ):
         """
-        Get all package versions for a package owned by an organization
-        https://docs.github.com/rest/reference/packages#get-all-package-versions-for-a-package-owned-by-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        Payload Parameters:
-        page
-         per-page
-         state
+        Summary:
+        List package versions for a package owned by an organization
+        Docs:
+        https://docs.github.com/rest/packages#get-all-package-versions-for-a-package-owned-by-an-organization
         """
         url = self._base_url + f"/orgs/{org}/packages/{package_type}/{package_name}/versions"
         response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def get_a_package_version_for_an_organization(
-        self, package_type, package_name, org, package_version_id, params=None, payload=None
+        self,
+        package_type,
+        package_name,
+        org,
+        package_version_id,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         Get a package version for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#get-a-package-version-for-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -129,19 +102,19 @@ class Packages:
         return response
 
     def delete_package_version_for_an_organization(
-        self, package_type, package_name, org, package_version_id, params=None, payload=None
+        self,
+        package_type,
+        package_name,
+        org,
+        package_version_id,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         Delete package version for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#delete-a-package-version-for-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -151,37 +124,33 @@ class Packages:
         return response
 
     def restore_package_version_for_an_organization(
-        self, package_type, package_name, org, package_version_id, params=None, payload=None
+        self,
+        package_type,
+        package_name,
+        org,
+        package_version_id,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         Restore package version for an organization
+        Docs:
         https://docs.github.com/rest/reference/packages#restore-a-package-version-for-an-organization
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        org
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/orgs/{org}/packages/{package_type}/{package_name}/versions/{package_version_id}/restore"  # pylint: disable=line-too-long # noqa: E501
+            + f"/orgs/{org}/packages/{package_type}/{package_name}/versions/{package_version_id}/restore"
         )
         response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def list_packages_for_the_authenticated_users_namespace(self, params=None, payload=None):
         """
+        Summary:
         List packages for the authenticated user's namespace
+        Docs:
         https://docs.github.com/rest/reference/packages#list-packages-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-        package_type
-         package-visibility
         """
         url = self._base_url + "/user/packages"
         response = self._execute("get", url, params=params, payload=payload)
@@ -191,14 +160,10 @@ class Packages:
         self, package_type, package_name, params=None, payload=None
     ):
         """
+        Summary:
         Get a package for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/packages#get-a-package-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/packages/{package_type}/{package_name}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -208,14 +173,10 @@ class Packages:
         self, package_type, package_name, params=None, payload=None
     ):
         """
+        Summary:
         Delete a package for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/packages#delete-a-package-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        Payload Parameters:
-
         """
         url = self._base_url + f"/user/packages/{package_type}/{package_name}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -225,33 +186,23 @@ class Packages:
         self, package_type, package_name, params=None, payload=None
     ):
         """
+        Summary:
         Restore a package for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/packages#restore-a-package-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        Payload Parameters:
-        token
         """
         url = self._base_url + f"/user/packages/{package_type}/{package_name}/restore"
         response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_all_package_versions_for_a_package_owned_by_the_authenticated_user(
+    def list_package_versions_for_a_package_owned_by_the_authenticated_user(
         self, package_type, package_name, params=None, payload=None
     ):
         """
-        Get all package versions for a package owned by the authenticated user
-        https://docs.github.com/rest/reference/packages#get-all-package-versions-for-a-package-owned-by-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        Payload Parameters:
-        page
-         per-page
-         state
+        Summary:
+        List package versions for a package owned by the authenticated user
+        Docs:
+        https://docs.github.com/rest/packages#get-all-package-versions-for-a-package-owned-by-the-authenticated-user
         """
         url = self._base_url + f"/user/packages/{package_type}/{package_name}/versions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -261,15 +212,10 @@ class Packages:
         self, package_type, package_name, package_version_id, params=None, payload=None
     ):
         """
+        Summary:
         Get a package version for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/packages#get-a-package-version-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -282,15 +228,10 @@ class Packages:
         self, package_type, package_name, package_version_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete a package version for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/packages#delete-a-package-version-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -303,15 +244,10 @@ class Packages:
         self, package_type, package_name, package_version_id, params=None, payload=None
     ):
         """
+        Summary:
         Restore a package version for the authenticated user
+        Docs:
         https://docs.github.com/rest/reference/packages#restore-a-package-version-for-the-authenticated-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -322,14 +258,10 @@ class Packages:
 
     def list_packages_for_a_user(self, username, params=None, payload=None):
         """
+        Summary:
         List packages for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#list-packages-for-user
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        package_type
-         package-visibility
         """
         url = self._base_url + f"/users/{username}/packages"
         response = self._execute("get", url, params=params, payload=payload)
@@ -339,15 +271,10 @@ class Packages:
         self, package_type, package_name, username, params=None, payload=None
     ):
         """
+        Summary:
         Get a package for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#get-a-package-for-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/users/{username}/packages/{package_type}/{package_name}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -357,15 +284,10 @@ class Packages:
         self, package_type, package_name, username, params=None, payload=None
     ):
         """
+        Summary:
         Delete a package for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#delete-a-package-for-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/users/{username}/packages/{package_type}/{package_name}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -375,100 +297,90 @@ class Packages:
         self, package_type, package_name, username, params=None, payload=None
     ):
         """
+        Summary:
         Restore a package for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#restore-a-package-for-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        username
-        Payload Parameters:
-        token
         """
         url = self._base_url + f"/users/{username}/packages/{package_type}/{package_name}/restore"
         response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def get_all_package_versions_for_a_package_owned_by_a_user(
+    def list_package_versions_for_a_package_owned_by_a_user(
         self, package_type, package_name, username, params=None, payload=None
     ):
         """
-        Get all package versions for a package owned by a user
-        https://docs.github.com/rest/reference/packages#get-all-package-versions-for-a-package-owned-by-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        username
-        Payload Parameters:
-
+        Summary:
+        List package versions for a package owned by a user
+        Docs:
+        https://docs.github.com/rest/packages#get-all-package-versions-for-a-package-owned-by-a-user
         """
         url = self._base_url + f"/users/{username}/packages/{package_type}/{package_name}/versions"
         response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def get_a_package_version_for_a_user(
-        self, package_type, package_name, package_version_id, username, params=None, payload=None
+        self,
+        package_type,
+        package_name,
+        package_version_id,
+        username,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         Get a package version for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#get-a-package-version-for-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        package_version_id
-        username
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/users/{username}/packages/{package_type}/{package_name}/versions/{package_version_id}"  # pylint: disable=line-too-long # noqa: E501
+            + f"/users/{username}/packages/{package_type}/{package_name}/versions/{package_version_id}"
         )
         response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def delete_package_version_for_a_user(
-        self, package_type, package_name, username, package_version_id, params=None, payload=None
+        self,
+        package_type,
+        package_name,
+        username,
+        package_version_id,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         Delete package version for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#delete-a-package-version-for-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        username
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/users/{username}/packages/{package_type}/{package_name}/versions/{package_version_id}"  # pylint: disable=line-too-long # noqa: E501
+            + f"/users/{username}/packages/{package_type}/{package_name}/versions/{package_version_id}"
         )
         response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def restore_package_version_for_a_user(
-        self, package_type, package_name, username, package_version_id, params=None, payload=None
+        self,
+        package_type,
+        package_name,
+        username,
+        package_version_id,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         Restore package version for a user
+        Docs:
         https://docs.github.com/rest/reference/packages#restore-a-package-version-for-a-user
-        Attributes:
-        Path Parameters:
-        package_type
-        package_name
-        username
-        package_version_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/users/{username}/packages/{package_type}/{package_name}/versions/{package_version_id}/restore"  # pylint: disable=line-too-long # noqa: E501
+            + f"/users/{username}/packages/{package_type}/{package_name}/versions/{package_version_id}/restore"
         )
         response = self._execute("post", url, params=params, payload=payload)
         return response
