@@ -1,33 +1,27 @@
 """
 Interact with GitHub Projects.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Projects:
-    # pylint: disable=too-many-public-methods
     """
     Interact with GitHub Projects.
     """
 
     def __init__(self, client):
         """
-        Initialize the Projects class.
+        Initializes the Projects class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_organization_projects(self, org, params=None, payload=None):
         """
+        Summary:
         List organization projects
+        Docs:
         https://docs.github.com/rest/reference/projects#list-organization-projects
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-        state
-         per-page
-         page
         """
         url = self._base_url + f"/orgs/{org}/projects"
         response = self._execute("get", url, params=params, payload=payload)
@@ -35,13 +29,10 @@ class Projects:
 
     def create_an_organization_project(self, org, params=None, payload=None):
         """
+        Summary:
         Create an organization project
+        Docs:
         https://docs.github.com/rest/reference/projects#create-an-organization-project
-        Attributes:
-        Path Parameters:
-        org
-        Payload Parameters:
-
         """
         url = self._base_url + f"/orgs/{org}/projects"
         response = self._execute("post", url, params=params, payload=payload)
@@ -49,13 +40,10 @@ class Projects:
 
     def get_a_project_card(self, card_id, params=None, payload=None):
         """
+        Summary:
         Get a project card
+        Docs:
         https://docs.github.com/rest/reference/projects#get-a-project-card
-        Attributes:
-        Path Parameters:
-        card_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/cards/{card_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -63,13 +51,10 @@ class Projects:
 
     def update_an_existing_project_card(self, card_id, params=None, payload=None):
         """
+        Summary:
         Update an existing project card
+        Docs:
         https://docs.github.com/rest/reference/projects#update-a-project-card
-        Attributes:
-        Path Parameters:
-        card_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/cards/{card_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -77,13 +62,10 @@ class Projects:
 
     def delete_a_project_card(self, card_id, params=None, payload=None):
         """
+        Summary:
         Delete a project card
+        Docs:
         https://docs.github.com/rest/reference/projects#delete-a-project-card
-        Attributes:
-        Path Parameters:
-        card_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/cards/{card_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -91,13 +73,10 @@ class Projects:
 
     def move_a_project_card(self, card_id, params=None, payload=None):
         """
+        Summary:
         Move a project card
+        Docs:
         https://docs.github.com/rest/reference/projects#move-a-project-card
-        Attributes:
-        Path Parameters:
-        card_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/cards/{card_id}/moves"
         response = self._execute("post", url, params=params, payload=payload)
@@ -105,13 +84,10 @@ class Projects:
 
     def get_a_project_column(self, column_id, params=None, payload=None):
         """
+        Summary:
         Get a project column
+        Docs:
         https://docs.github.com/rest/reference/projects#get-a-project-column
-        Attributes:
-        Path Parameters:
-        column_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/{column_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -119,13 +95,10 @@ class Projects:
 
     def update_an_existing_project_column(self, column_id, params=None, payload=None):
         """
+        Summary:
         Update an existing project column
+        Docs:
         https://docs.github.com/rest/reference/projects#update-a-project-column
-        Attributes:
-        Path Parameters:
-        column_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/{column_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -133,13 +106,10 @@ class Projects:
 
     def delete_a_project_column(self, column_id, params=None, payload=None):
         """
+        Summary:
         Delete a project column
+        Docs:
         https://docs.github.com/rest/reference/projects#delete-a-project-column
-        Attributes:
-        Path Parameters:
-        column_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/{column_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -147,15 +117,10 @@ class Projects:
 
     def list_project_cards(self, column_id, params=None, payload=None):
         """
+        Summary:
         List project cards
+        Docs:
         https://docs.github.com/rest/reference/projects#list-project-cards
-        Attributes:
-        Path Parameters:
-        column_id
-        Payload Parameters:
-        archived_state
-         per-page
-         page
         """
         url = self._base_url + f"/projects/columns/{column_id}/cards"
         response = self._execute("get", url, params=params, payload=payload)
@@ -163,13 +128,10 @@ class Projects:
 
     def create_a_project_card(self, column_id, params=None, payload=None):
         """
+        Summary:
         Create a project card
+        Docs:
         https://docs.github.com/rest/reference/projects#create-a-project-card
-        Attributes:
-        Path Parameters:
-        column_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/{column_id}/cards"
         response = self._execute("post", url, params=params, payload=payload)
@@ -177,13 +139,10 @@ class Projects:
 
     def move_a_project_column(self, column_id, params=None, payload=None):
         """
+        Summary:
         Move a project column
+        Docs:
         https://docs.github.com/rest/reference/projects#move-a-project-column
-        Attributes:
-        Path Parameters:
-        column_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/columns/{column_id}/moves"
         response = self._execute("post", url, params=params, payload=payload)
@@ -191,13 +150,10 @@ class Projects:
 
     def get_a_project(self, project_id, params=None, payload=None):
         """
+        Summary:
         Get a project
+        Docs:
         https://docs.github.com/rest/reference/projects#get-a-project
-        Attributes:
-        Path Parameters:
-        project_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -205,13 +161,10 @@ class Projects:
 
     def update_a_project(self, project_id, params=None, payload=None):
         """
+        Summary:
         Update a project
+        Docs:
         https://docs.github.com/rest/reference/projects#update-a-project
-        Attributes:
-        Path Parameters:
-        project_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -219,13 +172,10 @@ class Projects:
 
     def delete_a_project(self, project_id, params=None, payload=None):
         """
+        Summary:
         Delete a project
+        Docs:
         https://docs.github.com/rest/reference/projects#delete-a-project
-        Attributes:
-        Path Parameters:
-        project_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -233,15 +183,10 @@ class Projects:
 
     def list_project_collaborators(self, project_id, params=None, payload=None):
         """
+        Summary:
         List project collaborators
+        Docs:
         https://docs.github.com/rest/reference/projects#list-project-collaborators
-        Attributes:
-        Path Parameters:
-        project_id
-        Payload Parameters:
-        affiliation
-         per-page
-         page
         """
         url = self._base_url + f"/projects/{project_id}/collaborators"
         response = self._execute("get", url, params=params, payload=payload)
@@ -249,14 +194,10 @@ class Projects:
 
     def add_project_collaborator(self, project_id, username, params=None, payload=None):
         """
+        Summary:
         Add project collaborator
+        Docs:
         https://docs.github.com/rest/reference/projects#add-project-collaborator
-        Attributes:
-        Path Parameters:
-        project_id
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}/collaborators/{username}"
         response = self._execute("put", url, params=params, payload=payload)
@@ -264,14 +205,10 @@ class Projects:
 
     def remove_user_as_a_collaborator(self, project_id, username, params=None, payload=None):
         """
+        Summary:
         Remove user as a collaborator
+        Docs:
         https://docs.github.com/rest/reference/projects#remove-project-collaborator
-        Attributes:
-        Path Parameters:
-        project_id
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}/collaborators/{username}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -279,14 +216,10 @@ class Projects:
 
     def get_project_permission_for_a_user(self, project_id, username, params=None, payload=None):
         """
+        Summary:
         Get project permission for a user
+        Docs:
         https://docs.github.com/rest/reference/projects#get-project-permission-for-a-user
-        Attributes:
-        Path Parameters:
-        project_id
-        username
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}/collaborators/{username}/permission"
         response = self._execute("get", url, params=params, payload=payload)
@@ -294,14 +227,10 @@ class Projects:
 
     def list_project_columns(self, project_id, params=None, payload=None):
         """
+        Summary:
         List project columns
+        Docs:
         https://docs.github.com/rest/reference/projects#list-project-columns
-        Attributes:
-        Path Parameters:
-        project_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/projects/{project_id}/columns"
         response = self._execute("get", url, params=params, payload=payload)
@@ -309,13 +238,10 @@ class Projects:
 
     def create_a_project_column(self, project_id, params=None, payload=None):
         """
+        Summary:
         Create a project column
+        Docs:
         https://docs.github.com/rest/reference/projects#create-a-project-column
-        Attributes:
-        Path Parameters:
-        project_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/projects/{project_id}/columns"
         response = self._execute("post", url, params=params, payload=payload)
@@ -323,16 +249,10 @@ class Projects:
 
     def list_repository_projects(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List repository projects
+        Docs:
         https://docs.github.com/rest/reference/projects#list-repository-projects
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        state
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/projects"
         response = self._execute("get", url, params=params, payload=payload)
@@ -340,14 +260,10 @@ class Projects:
 
     def create_a_repository_project(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a repository project
+        Docs:
         https://docs.github.com/rest/reference/projects#create-a-repository-project
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/projects"
         response = self._execute("post", url, params=params, payload=payload)
@@ -355,13 +271,10 @@ class Projects:
 
     def create_a_user_project(self, params=None, payload=None):
         """
+        Summary:
         Create a user project
+        Docs:
         https://docs.github.com/rest/reference/projects#create-a-user-project
-        Attributes:
-        Path Parameters:
-
-        Payload Parameters:
-
         """
         url = self._base_url + "/user/projects"
         response = self._execute("post", url, params=params, payload=payload)
@@ -369,15 +282,10 @@ class Projects:
 
     def list_user_projects(self, username, params=None, payload=None):
         """
+        Summary:
         List user projects
+        Docs:
         https://docs.github.com/rest/reference/projects#list-user-projects
-        Attributes:
-        Path Parameters:
-        username
-        Payload Parameters:
-        state
-         per-page
-         page
         """
         url = self._base_url + f"/users/{username}/projects"
         response = self._execute("get", url, params=params, payload=payload)
