@@ -1,38 +1,27 @@
 """
 Interact with GitHub Pull Requests.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Pulls:
-    # pylint: disable=too-many-public-methods
     """
     Interact with GitHub Pull Requests.
     """
 
     def __init__(self, client):
         """
-        Initialize the Pulls class.
+        Initializes the Pulls class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_pull_requests(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List pull requests
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-pull-requests
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        state
-         head
-         base
-         sort
-         direction
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls"
         response = self._execute("get", url, params=params, payload=payload)
@@ -40,14 +29,10 @@ class Pulls:
 
     def create_a_pull_request(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         Create a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#create-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls"
         response = self._execute("post", url, params=params, payload=payload)
@@ -55,18 +40,10 @@ class Pulls:
 
     def list_review_comments_in_a_repository(self, owner, repo, params=None, payload=None):
         """
+        Summary:
         List review comments in a repository
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-review-comments-in-a-repository
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        Payload Parameters:
-        sort
-         direction
-         since
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments"
         response = self._execute("get", url, params=params, payload=payload)
@@ -76,15 +53,10 @@ class Pulls:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Get a review comment for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#get-a-review-comment-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -94,15 +66,10 @@ class Pulls:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Update a review comment for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#update-a-review-comment-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -112,15 +79,10 @@ class Pulls:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete a review comment for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#delete-a-review-comment-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -128,15 +90,10 @@ class Pulls:
 
     def get_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         Get a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#get-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -144,15 +101,10 @@ class Pulls:
 
     def update_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         Update a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls/#update-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}"
         response = self._execute("patch", url, params=params, payload=payload)
@@ -162,19 +114,10 @@ class Pulls:
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
+        Summary:
         List review comments on a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-review-comments-on-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-        sort
-         direction
-         since
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments"
         response = self._execute("get", url, params=params, payload=payload)
@@ -184,15 +127,10 @@ class Pulls:
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
+        Summary:
         Create a review comment for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#create-a-review-comment-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments"
         response = self._execute("post", url, params=params, payload=payload)
@@ -202,16 +140,10 @@ class Pulls:
         self, owner, repo, pull_number, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Create a reply for a review comment
+        Docs:
         https://docs.github.com/rest/reference/pulls#create-a-reply-for-a-review-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        comment_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -222,16 +154,10 @@ class Pulls:
 
     def list_commits_on_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         List commits on a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-commits-on-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/commits"
         response = self._execute("get", url, params=params, payload=payload)
@@ -239,16 +165,10 @@ class Pulls:
 
     def list_pull_requests_files(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         List pull requests files
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-pull-requests-files
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/files"
         response = self._execute("get", url, params=params, payload=payload)
@@ -258,15 +178,10 @@ class Pulls:
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
+        Summary:
         Check if a pull request has been merged
+        Docs:
         https://docs.github.com/rest/reference/pulls#check-if-a-pull-request-has-been-merged
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/merge"
         response = self._execute("get", url, params=params, payload=payload)
@@ -274,34 +189,23 @@ class Pulls:
 
     def merge_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         Merge a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#merge-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/merge"
         response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def list_requested_reviewers_for_a_pull_request(
+    def get_all_requested_reviewers_for_a_pull_request(
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
-        List requested reviewers for a pull request
-        https://docs.github.com/rest/reference/pulls#list-requested-reviewers-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-        per-page
-         page
+        Summary:
+        Get all requested reviewers for a pull request
+        Docs:
+        https://docs.github.com/rest/reference/pulls#get-all-requested-reviewers-for-a-pull-request
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
         response = self._execute("get", url, params=params, payload=payload)
@@ -311,15 +215,10 @@ class Pulls:
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
+        Summary:
         Request reviewers for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#request-reviewers-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
         response = self._execute("post", url, params=params, payload=payload)
@@ -329,15 +228,10 @@ class Pulls:
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
+        Summary:
         Remove requested reviewers from a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#remove-requested-reviewers-from-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -345,16 +239,10 @@ class Pulls:
 
     def list_reviews_for_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         List reviews for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-reviews-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-        per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews"
         response = self._execute("get", url, params=params, payload=payload)
@@ -364,15 +252,10 @@ class Pulls:
         self, owner, repo, pull_number, params=None, payload=None
     ):
         """
+        Summary:
         Create a review for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#create-a-review-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews"
         response = self._execute("post", url, params=params, payload=payload)
@@ -382,16 +265,10 @@ class Pulls:
         self, owner, repo, pull_number, review_id, params=None, payload=None
     ):
         """
+        Summary:
         Get a review for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#get-a-review-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        review_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
         response = self._execute("get", url, params=params, payload=payload)
@@ -401,16 +278,10 @@ class Pulls:
         self, owner, repo, pull_number, review_id, params=None, payload=None
     ):
         """
+        Summary:
         Update a review for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#update-a-review-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        review_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
         response = self._execute("put", url, params=params, payload=payload)
@@ -420,16 +291,10 @@ class Pulls:
         self, owner, repo, pull_number, review_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete a pending review for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#delete-a-pending-review-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        review_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
         response = self._execute("delete", url, params=params, payload=payload)
@@ -439,17 +304,10 @@ class Pulls:
         self, owner, repo, pull_number, review_id, params=None, payload=None
     ):
         """
+        Summary:
         List comments for a pull request review
+        Docs:
         https://docs.github.com/rest/reference/pulls#list-comments-for-a-pull-request-review
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        review_id
-        Payload Parameters:
-        per-page
-         page
         """
         url = (
             self._base_url
@@ -462,16 +320,10 @@ class Pulls:
         self, owner, repo, pull_number, review_id, params=None, payload=None
     ):
         """
+        Summary:
         Dismiss a review for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#dismiss-a-review-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        review_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -484,16 +336,10 @@ class Pulls:
         self, owner, repo, pull_number, review_id, params=None, payload=None
     ):
         """
+        Summary:
         Submit a review for a pull request
+        Docs:
         https://docs.github.com/rest/reference/pulls#submit-a-review-for-a-pull-request
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        review_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/events"
@@ -501,134 +347,12 @@ class Pulls:
         response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def list_comments_in_a_pull_request_thread(
-        self, owner, repo, pull_number, thread_id, params=None, payload=None
-    ):
-        """
-        List comments in a pull request thread
-        https://docs.github.com/rest/reference/pulls#list-thread-comments-in-a-thread
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        Payload Parameters:
-        per-page
-         page
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments"
-        )
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
-    def create_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, params=None, payload=None
-    ):
-        """
-        Create a pull request thread comment
-        https://docs.github.com/rest/reference/pulls#create-a-thread-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        Payload Parameters:
-
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments"
-        )
-        response = self._execute("post", url, params=params, payload=payload)
-        return response
-
-    def get_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
-    ):
-
-        """
-        Get a pull request thread comment
-        https://docs.github.com/rest/reference/pulls#get-a-thread-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        comment_id
-        Payload Parameters:
-
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
-        )
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
-    def update_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
-    ):
-
-        """
-        Update a pull request thread comment
-        https://docs.github.com/rest/reference/pulls#update-a-thread-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        comment_id
-        Payload Parameters:
-
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
-        )
-        response = self._execute("patch", url, params=params, payload=payload)
-        return response
-
-    def delete_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
-    ):
-
-        """
-        Delete a pull request thread comment
-        https://docs.github.com/rest/reference/pulls#delete-a-thread-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        comment_id
-        Payload Parameters:
-
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
-        )
-        response = self._execute("delete", url, params=params, payload=payload)
-        return response
-
     def update_a_pull_request_branch(self, owner, repo, pull_number, params=None, payload=None):
         """
+        Summary:
         Update a pull request branch
+        Docs:
         https://docs.github.com/rest/reference/pulls#update-a-pull-request-branch
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/update-branch"
         response = self._execute("put", url, params=params, payload=payload)
