@@ -1,4 +1,6 @@
 """
 Init for file for repos package.
 """
-from .repos import Repos  # noqa: F401
+# flake8: noqa
+
+from .repos import Repos
